@@ -1,11 +1,11 @@
-;;; eudc-export.el --- Functions to export EUDC qeuery results
+;;; eudc-export.el --- functions to export EUDC query results
 
 ;; Copyright (C) 1998 Free Software Foundation, Inc.
 
 ;; Author: Oscar Figueiredo <oscar@xemacs.org>
 ;; Maintainer: Oscar Figueiredo <oscar@xemacs.org>
 ;; Created: Jun 1999
-;; Version: $Revision: 1.2 $
+;; Version: $Revision: 1.4 $
 ;; Keywords: help
 
 ;; This file is part of XEmacs
@@ -44,14 +44,12 @@
 RECORD is an alist of (KEY . VALUE) where KEY is a directory attribute name
 symbol and VALUE is the corresponding value for the record.
 If SILENT is non-nil then the created BBDB record is not displayed."
-  ;; This function runs in a special context where lisp symbols corresponding
-  ;; to field names in record are bound to the corresponding values
   (eval 
    `(let* (,@(mapcar '(lambda (c)
 			(list (car c) (if (listp (cdr c))
 					  (list 'quote (cdr c))
 					(cdr c))))
-		     record)
+		     (cdr record))
 	     bbdb-name
 	     bbdb-company
 	     bbdb-net
@@ -61,8 +59,12 @@ If SILENT is non-nil then the created BBDB record is not displayed."
 	     spec
 	     bbdb-record
 	     value
-	     (conversion-alist (symbol-value eudc-bbdb-conversion-alist)))
-
+	     conversion-alist)
+      
+      (eudc-server-protect 
+       (eudc-set-server (caar record) (cdar record))
+       (setq conversion-alist (symbol-value eudc-bbdb-conversion-alist)))
+      
       ;; BBDB standard fields
       (setq bbdb-name (eudc-parse-spec (cdr (assq 'name conversion-alist)) record nil)
 	    bbdb-company (eudc-parse-spec (cdr (assq 'company conversion-alist)) record nil)
@@ -70,14 +72,14 @@ If SILENT is non-nil then the created BBDB record is not displayed."
 	    bbdb-notes (eudc-parse-spec (cdr (assq 'notes conversion-alist)) record nil))
       (setq spec (cdr (assq 'address conversion-alist)))
       (setq bbdb-address (delq nil (eudc-parse-spec (if (listp (car spec))
-						      spec
-						    (list spec))
-						  record t)))
+							spec
+						      (list spec))
+						    record t)))
       (setq spec (cdr (assq 'phone conversion-alist)))
       (setq bbdb-phones (delq nil (eudc-parse-spec (if (listp (car spec))
-						     spec
-						   (list spec))
-						 record t)))
+						       spec
+						     (list spec))
+						   record t)))
       ;; BBDB custom fields
       (setq bbdb-notes (append (list (and bbdb-notes (cons 'notes bbdb-notes)))
 			       (mapcar (function
@@ -96,7 +98,7 @@ If SILENT is non-nil then the created BBDB record is not displayed."
 					      bbdb-notes))
       (or silent
 	  (bbdb-display-records (list bbdb-record))))))
-
+  
 (defun eudc-parse-spec (spec record recurse)
   "Parse the conversion SPEC using RECORD.
 If RECURSE is non-nil then SPEC may be a list of atomic specs."
